Struct
QmiMessageWmsIndicationRegisterInput
since: 1.38
Description [src]
struct QmiMessageWmsIndicationRegisterInput {
/* No available fields */
}
The QmiMessageWmsIndicationRegisterInput structure contains private data and should only be accessed
using the provided API.
Available since: 1.38
Constructors
qmi_message_wms_indication_register_input_new
Allocates a new QmiMessageWmsIndicationRegisterInput.
since: 1.38
Instance methods
qmi_message_wms_indication_register_input_get_report_transport_network_registration_status
Get the ‘Report Transport Network Registration Status’ field from self.
since: 1.38
qmi_message_wms_indication_register_input_ref
Atomically increments the reference count of self by one.
since: 1.38
qmi_message_wms_indication_register_input_set_report_transport_network_registration_status
Set the ‘Report Transport Network Registration Status’ field in the message.
since: 1.38
qmi_message_wms_indication_register_input_unref
Atomically decrements the reference count of self by one.
If the reference count drops to 0, self is completely disposed.
since: 1.38